@@ -51,6 +51,12 @@ const matrixConfig = [
     run_cmd: "bun run",
     templates: nodeJsTemplates,
   },
+  {
+    manager: "deno",
+    install_cmd: "deno install",
+    run_cmd: "deno task",
+    templates: nodeJsTemplates,
+  },
   {
     manager: "dotnet",
     install_cmd: "",
@@ -78,6 +84,7 @@ matrixConfig
       ) {
         const jobInfo = {
           template: t,
+          node: ["pnpm", "yarn", "npm"].includes(managerInfo.manager),
           install_trunk: ["yew", "sycamore", "leptos"].includes(t),
           install_dioxus_cli: t === "dioxus",
           tauriVersion: "latest",
